$user = 'root'
$pswd = 'XXXXX'

$cred = New-Object PSCredential -ArgumentList $user,(ConvertTo-SecureString -String $pswd -AsPlainText -Force)

Get-VMHost -PipelineVariable esx |
ForEach-Object -Process {
    $sshService = Get-VMHostService -VMHost $_ | where{$_.Key -eq 'TSM-SSH'}
    if(-not $sshService.Running){
        Start-VMHostService -HostService $sshService -Confirm:$false | Out-Null
    }

    $session = New-SSHSession -ComputerName $_.Name -Credential $cred –AcceptKey
    $result = Invoke-SSHCommand -SSHSession $session -Command 'ntpq -p'
    Remove-SSHSession -SSHSession $session | Out-Null

    $obj = [pscustomobject]@{
        VMHost = $esx.Name
        'NTP Service Running' = Get-VMHostService -VMHost $_ | where{$_.Key -eq 'ntpd'} | select -ExpandProperty Running
        'NTP Server(s)' = (Get-View -Id $_.ExtensionData.ConfigManager.DatetimeSystem).DateTimeInfo.NtpConfig.Server -join '| '
    }
    if($result.Output[0].Length -eq 0){
        Write-Host "No output from 'ntpq -p' on $($esx.Name)"
    }
    else{
        $fields = (($result.Output | where{$_ -match '^\*'}) -replace '\s+',' ').Split(' ')
        Add-Member -InputObject $obj -Name 'Reach' -Value $fields[6] -MemberType NoteProperty
        Add-Member -InputObject $obj -Name 'Delay' -Value $fields[7] -MemberType NoteProperty
        Add-Member -InputObject $obj -Name 'Offset' -Value $fields[8] -MemberType NoteProperty
        Add-Member -InputObject $obj -Name 'Jitter' -Value $fields[9] -MemberType NoteProperty
    }
    $obj
    if(-not $sshService.Running){
        Stop-VMHostService -HostService $sshService -Confirm:$false | Out-Null
    }
} |
Sort-Object -Property {$_.psObject.Properties.Name.Count} -Descending |
Export-Csv -Path 'D:\Akshay\YUL-V720-VMVC01.csv' -NoTypeInformation -UseCulture
